@@ -14,19 +14,20 @@ from os import makedirs
 from os.path import basename, dirname, exists, expanduser, join
 from urllib.request import urlopen
 
+try:
+    from importlib import metadata
+except ImportError:
+    import importlib_metadata as metadata
+
 import inators
-import pkg_resources
 
 
-__version__ = pkg_resources.get_distribution(__package__).version
+__version__ = metadata.version(__package__)
 
-__antlr_version__ = None
-for dist_spec in ('antlr4-python3-runtime', 'antlr4-python2-runtime'):
-    try:
-        __antlr_version__ = pkg_resources.get_distribution(dist_spec).version
-        break
-    except pkg_resources.DistributionNotFound:
-        pass
+try:
+    __antlr_version__ = metadata.version('antlr4-python3-runtime')
+except metadata.PackageNotFoundError:
+    __antlr_version__ = None
 
 
 def default_antlr_jar_path(version=None):
@@ -71,7 +72,7 @@ def download(version=None, path=None, *, force=False, lazy=False):
         if not force:
             raise OSError(errno.EEXIST, 'file already exists', tool_path)
 
-    ssl_context = ssl.create_default_context(purpose=ssl.Purpose.CLIENT_AUTH)
+    ssl_context = ssl.create_default_context(purpose=ssl.Purpose.SERVER_AUTH)
     with contextlib.closing(urlopen(tool_url, context=ssl_context)) as response:
         tool_bytes = response.read()
 
